@@ -25,9 +25,10 @@ import os
 import time
 import types
 from collections import abc
-from test.helpers import (
+from test.helpers_shared import (
     AWS_CREDS,
     AWS_CREDS_2,
+    AWS_TEMP_CREDS,
     AZURE_CREDS,
     CA_PEM,
     CLIENT_PEM,
@@ -108,6 +109,7 @@ PLACEHOLDER_MAP = {}
 for provider_name, provider_data in [
     ("local", {"key": LOCAL_MASTER_KEY}),
     ("local:name1", {"key": LOCAL_MASTER_KEY}),
+    ("aws_temp", AWS_TEMP_CREDS),
     ("aws", AWS_CREDS),
     ("aws:name1", AWS_CREDS),
     ("aws:name2", AWS_CREDS_2),
@@ -122,6 +124,9 @@ for provider_name, provider_data in [
         placeholder = f"/clientEncryptionOpts/kmsProviders/{provider_name}/{key}"
         PLACEHOLDER_MAP[placeholder] = value
 
+        placeholder = f"/autoEncryptOpts/kmsProviders/{provider_name}/{key}"
+        PLACEHOLDER_MAP[placeholder] = value
+
 OIDC_ENV = os.environ.get("OIDC_ENV", "test")
 if OIDC_ENV == "test":
     PLACEHOLDER_MAP["/uriOptions/authMechanismProperties"] = {"ENVIRONMENT": "test"}
