@@ -120,9 +120,9 @@ replacements = {
     "_async_create_lock": "_create_lock",
     "_async_create_condition": "_create_condition",
     "_async_cond_wait": "_cond_wait",
+    "async_receive_kms": "receive_kms",
     "AsyncNetworkingInterface": "NetworkingInterface",
     "_configured_protocol_interface": "_configured_socket_interface",
-    "_async_configured_socket": "_configured_socket",
     "SpecRunnerTask": "SpecRunnerThread",
     "AsyncMockConnection": "MockConnection",
     "AsyncMockPool": "MockPool",
@@ -205,12 +205,14 @@ converted_tests = [
     "utils_spec_runner.py",
     "qcheck.py",
     "test_auth.py",
+    "test_auth_oidc.py",
     "test_auth_spec.py",
     "test_bulk.py",
     "test_change_stream.py",
     "test_client.py",
     "test_client_bulk_write.py",
     "test_client_context.py",
+    "test_client_metadata.py",
     "test_collation.py",
     "test_collection.py",
     "test_collection_management.py",
@@ -417,13 +419,18 @@ def unasync_directory(files: list[str], src: str, dest: str, replacements: dict[
 def main() -> None:
     modified_files = [f"./{f}" for f in sys.argv[1:]]
     errored = False
-    for fname in async_files + gridfs_files:
+    for fname in async_files + gridfs_files + test_files:
         # If the async file was modified, we don't need to check if the sync file was also modified.
         if str(fname) in modified_files:
             continue
         sync_name = str(fname).replace("asynchronous", "synchronous")
-        if sync_name in modified_files and "OVERRIDE_SYNCHRO_CHECK" not in os.environ:
-            print(f"Refusing to overwrite {sync_name}")
+        test_sync_name = str(fname).replace("/asynchronous", "")
+        if (
+            sync_name in modified_files
+            or test_sync_name in modified_files
+            and "OVERRIDE_SYNCHRO_CHECK" not in os.environ
+        ):
+            print(f"Refusing to overwrite {test_sync_name}")
             errored = True
     if errored:
         raise ValueError("Aborting synchro due to errors")
